@@ -1,4 +1,4 @@
-__version__ = "0.1.5"
+__version__ = "0.1.7"
 
 from .m_array import *
 from .m_enum import *
@@ -7,6 +7,8 @@ from .m_variable import *
 __all__ = [
     "MArrayElement",
     "MArray",
+    "MArrayPointer",
+    "MArraySlidingWindow",
     "MArrayDirection",
     "MArrayElementComp",
     "MVariable",
